EnsuredBufferedInput

Enum EnsuredBufferedInput 

pub enum EnsuredBufferedInput<I>
where I: Input, I::Item: Copy + Default,
{ AlreadyBuffered(I), Buffered(BufferedInput<I>), }
Input value that is guaranteed to report itself as buffered.

This enum is returned by BufferedInput::ensure. It keeps an input that already buffers items as-is, and wraps an unbuffered input in BufferedInput. Operations delegate to the selected branch.

Variants



AlreadyBuffered(I)

The original input already reported itself as buffered.



Buffered(BufferedInput<I>)

The original input was wrapped in BufferedInput.