EnsuredBufferedOutput

Enum EnsuredBufferedOutput 

pub enum EnsuredBufferedOutput<O>
where O: Output, O::Item: Copy + Default,
{ AlreadyBuffered(O), Buffered(BufferedOutput<O>), }
Output value that is guaranteed to report itself as buffered.

This enum is returned by BufferedOutput::ensure. It keeps an output that already buffers items as-is, and wraps an unbuffered output in BufferedOutput. Operations delegate to the selected branch.

Variants



AlreadyBuffered(O)

The original output already reported itself as buffered.



Buffered(BufferedOutput<O>)

The original output was wrapped in BufferedOutput.