BufferedBinaryWriter

Struct BufferedBinaryWriter 

pub struct BufferedBinaryWriter<W, O = BigEndian> { /* private fields */ }
Buffered writer for fixed-width binary values.

Scalar writes encode directly into the internal output buffer and flush that buffer to the wrapped writer only when it becomes full or when explicitly flushed.

Flush contract

Pending buffered bytes are not flushed from Drop. Call Write::flush or Self::into_inner to guarantee that all bytes reach the wrapped writer. Self::get_ref and Self::get_mut can observe the wrapped writer before pending bytes have been flushed.

Implementations

Source

impl<W, O> BufferedBinaryWriter<W, O>
where O: ByteOrderSpec,

pub fn new(inner: W) -> Self

Creates a buffered binary writer with the default buffer capacity.

pub fn with_capacity(inner: W, capacity: usize) -> Self

Creates a buffered binary writer with at least capacity bytes.

pub const fn byte_order(&self) -> ByteOrder

Returns the byte order selected by this writer.

pub const fn get_ref(&self) -> &W

Returns a shared reference to the underlying writer.

Pending bytes may still be held in this wrapper’s internal buffer.

pub fn get_mut(&mut self) -> &mut W

Returns an exclusive reference to the underlying writer.

Pending bytes may still be held in this wrapper’s internal buffer. Flush first if the underlying writer must observe all previous writes.

Source

impl<W, O> BufferedBinaryWriter<W, O>
where W: Write, O: ByteOrderSpec,

pub fn into_inner(self) -> Result<W>

Flushes pending bytes and returns the underlying writer.

Source

impl<W> BufferedBinaryWriter<W, BigEndian>
where W: Write,

pub fn write_u8(&mut self, value: u8) -> Result<()>

Writes an unsigned 8-bit integer.

pub fn write_i8(&mut self, value: i8) -> Result<()>

Writes a signed 8-bit integer.

pub fn write_u16(&mut self, value: u16) -> Result<()>

Writes an unsigned 16-bit integer.

pub fn write_u32(&mut self, value: u32) -> Result<()>

Writes an unsigned 32-bit integer.

pub fn write_u64(&mut self, value: u64) -> Result<()>

Writes an unsigned 64-bit integer.

pub fn write_u128(&mut self, value: u128) -> Result<()>

Writes an unsigned 128-bit integer.

pub fn write_i16(&mut self, value: i16) -> Result<()>

Writes a signed 16-bit integer.

pub fn write_i32(&mut self, value: i32) -> Result<()>

Writes a signed 32-bit integer.

pub fn write_i64(&mut self, value: i64) -> Result<()>

Writes a signed 64-bit integer.

pub fn write_i128(&mut self, value: i128) -> Result<()>

Writes a signed 128-bit integer.

pub fn write_f32(&mut self, value: f32) -> Result<()>

Writes a 32-bit float.

pub fn write_f64(&mut self, value: f64) -> Result<()>

Writes a 64-bit float.

Source

impl<W> BufferedBinaryWriter<W, LittleEndian>
where W: Write,

pub fn write_u8(&mut self, value: u8) -> Result<()>

Writes an unsigned 8-bit integer.

pub fn write_i8(&mut self, value: i8) -> Result<()>

Writes a signed 8-bit integer.

pub fn write_u16(&mut self, value: u16) -> Result<()>

Writes an unsigned 16-bit integer.

pub fn write_u32(&mut self, value: u32) -> Result<()>

Writes an unsigned 32-bit integer.

pub fn write_u64(&mut self, value: u64) -> Result<()>

Writes an unsigned 64-bit integer.

pub fn write_u128(&mut self, value: u128) -> Result<()>

Writes an unsigned 128-bit integer.

pub fn write_i16(&mut self, value: i16) -> Result<()>

Writes a signed 16-bit integer.

pub fn write_i32(&mut self, value: i32) -> Result<()>

Writes a signed 32-bit integer.

pub fn write_i64(&mut self, value: i64) -> Result<()>

Writes a signed 64-bit integer.

pub fn write_i128(&mut self, value: i128) -> Result<()>

Writes a signed 128-bit integer.

pub fn write_f32(&mut self, value: f32) -> Result<()>

Writes a 32-bit float.

pub fn write_f64(&mut self, value: f64) -> Result<()>

Writes a 64-bit float.