CountingReader

Struct CountingReader 

pub struct CountingReader<R> { /* private fields */ }
Reader wrapper that counts successfully read bytes.

The count is increased only after the wrapped reader reports a successful byte count. Failed reads do not change the counter.

Examples

use std::io::{
    Cursor,
    Read,
};

use qubit_io::CountingReader;

let mut reader = CountingReader::new(Cursor::new(b"abc"));
let mut data = Vec::new();
reader.read_to_end(&mut data)?;

assert_eq!(b"abc", data.as_slice());
assert_eq!(3, reader.bytes_read());

Implementations

Source

impl<R> CountingReader<R>

pub fn new(inner: R) -> Self

Creates a counting reader.

Parameters
  • inner: Reader to wrap.
Returns

A new counting reader with a zero byte count.

pub fn bytes_read(&self) -> u64

Returns the number of bytes successfully read through this wrapper.

Returns

Total byte count. The value saturates at u64::MAX.

pub fn get_ref(&self) -> &R

Returns an immutable reference to the wrapped reader.

Returns

The wrapped reader reference.

pub fn get_mut(&mut self) -> &mut R

Returns a mutable reference to the wrapped reader.

Returns

The wrapped reader reference.

pub fn into_inner(self) -> R

Consumes this wrapper and returns the wrapped reader.

Returns

The wrapped reader.