pub struct Leb128Reader<R, P = NonStrict> { /* private fields */ }Expand description
Reader wrapper for LEB128 integers.
The decoding policy is selected by the P type parameter. Use
Leb128Reader<R, NonStrict> for permissive decoding and
Leb128Reader<R, Strict> for canonical-only decoding.
Target-width integers
usize and isize methods use the current Rust target’s pointer width.
Prefer fixed-width integer methods such as read_u64 or read_i64 for
persistent files and cross-platform protocols.
Implementations
Sourceimpl<R, P> Leb128Reader<R, P>where
P: DecodePolicy,
impl<R, P> Leb128Reader<R, P>where
P: DecodePolicy,
Sourcepub const fn is_strict(&self) -> bool
pub const fn is_strict(&self) -> bool
Returns whether this reader rejects non-canonical encodings.
Sourcepub fn into_inner(self) -> R
pub fn into_inner(self) -> R
Consumes this wrapper and returns the underlying reader.
Sourceimpl<R> Leb128Reader<R, NonStrict>where
R: Read,
impl<R> Leb128Reader<R, NonStrict>where
R: Read,
Sourcepub fn read_usize(&mut self) -> Result<usize>
pub fn read_usize(&mut self) -> Result<usize>
Reads an unsigned LEB128 usize.
Sourcepub fn read_isize(&mut self) -> Result<isize>
pub fn read_isize(&mut self) -> Result<isize>
Reads a signed LEB128 isize.
Sourcepub fn read_utf8_string(&mut self, max_len: usize) -> Result<String>
pub fn read_utf8_string(&mut self, max_len: usize) -> Result<String>
Reads a UTF-8 string prefixed by an unsigned LEB128 byte length.
The length prefix is decoded as usize, so this format is
target-width dependent. Prefer a fixed-width length prefix for
persistent files and cross-platform protocols.
Parameters
max_len: Maximum accepted UTF-8 payload length in bytes.
Returns
Returns the decoded UTF-8 string.
Errors
Returns an I/O error for length or payload reads, std::io::ErrorKind::InvalidData
when the encoded length exceeds max_len, or std::io::ErrorKind::InvalidData
when the payload is not valid UTF-8.
Sourceimpl<R> Leb128Reader<R, Strict>where
R: Read,
impl<R> Leb128Reader<R, Strict>where
R: Read,
Sourcepub fn read_usize(&mut self) -> Result<usize>
pub fn read_usize(&mut self) -> Result<usize>
Reads an unsigned LEB128 usize.
Sourcepub fn read_isize(&mut self) -> Result<isize>
pub fn read_isize(&mut self) -> Result<isize>
Reads a signed LEB128 isize.
Sourcepub fn read_utf8_string(&mut self, max_len: usize) -> Result<String>
pub fn read_utf8_string(&mut self, max_len: usize) -> Result<String>
Reads a UTF-8 string prefixed by an unsigned LEB128 byte length.
The length prefix is decoded as usize, so this format is
target-width dependent. Prefer a fixed-width length prefix for
persistent files and cross-platform protocols.
Parameters
max_len: Maximum accepted UTF-8 payload length in bytes.
Returns
Returns the decoded UTF-8 string.
Errors
Returns an I/O error for length or payload reads, std::io::ErrorKind::InvalidData
when the encoded length exceeds max_len, or std::io::ErrorKind::InvalidData
when the payload is not valid UTF-8.