pub struct Leb128Writer<W> { /* private fields */ }Expand description
Writer wrapper for canonical LEB128 integers.
Target-width integers
usize and isize methods use the current Rust target’s pointer width.
Prefer fixed-width integer methods such as write_u64 or write_i64 for
persistent files and cross-platform protocols.
Implementations
Sourceimpl<W> Leb128Writer<W>
impl<W> Leb128Writer<W>
Sourcepub fn into_inner(self) -> W
pub fn into_inner(self) -> W
Consumes this wrapper and returns the underlying writer.
Sourceimpl<W> Leb128Writer<W>where
W: Write,
impl<W> Leb128Writer<W>where
W: Write,
Sourcepub fn write_u128(&mut self, value: u128) -> Result<()>
pub fn write_u128(&mut self, value: u128) -> Result<()>
Writes an unsigned LEB128 u128.
Sourcepub fn write_usize(&mut self, value: usize) -> Result<()>
pub fn write_usize(&mut self, value: usize) -> Result<()>
Writes an unsigned LEB128 usize.
Sourcepub fn write_i128(&mut self, value: i128) -> Result<()>
pub fn write_i128(&mut self, value: i128) -> Result<()>
Writes a signed LEB128 i128.
Sourcepub fn write_isize(&mut self, value: isize) -> Result<()>
pub fn write_isize(&mut self, value: isize) -> Result<()>
Writes a signed LEB128 isize.
Sourcepub fn write_utf8_string(&mut self, value: &str) -> Result<()>
pub fn write_utf8_string(&mut self, value: &str) -> Result<()>
Writes a UTF-8 string prefixed by an unsigned LEB128 byte length.
The length prefix is encoded as usize, so this format is target-width
dependent. Prefer a fixed-width length prefix for persistent files and
cross-platform protocols.
Parameters
value: String slice to write.
Errors
Returns an I/O error from the underlying writer.