pub struct TokioOutput<T> { /* private fields */ }Expand description
Implementations
Sourceimpl<T> TokioOutput<T>
impl<T> TokioOutput<T>
Sourcepub const fn get_mut(&mut self) -> &mut T
pub const fn get_mut(&mut self) -> &mut T
Returns a mutable reference to the wrapped writer.
Returns
Returns the wrapped Tokio writer with mutable access.
Sourcepub fn get_pin_mut(self: Pin<&mut Self>) -> Pin<&mut T>
pub fn get_pin_mut(self: Pin<&mut Self>) -> Pin<&mut T>
Projects a pinned adapter to its pinned wrapped writer.
Returns
Returns a pinned mutable reference to the wrapped writer without moving it.
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T