WriteFuture

Struct WriteFuture 

pub struct WriteFuture<'a, O>
where O: AsyncOutput + ?Sized,
{ /* private fields */ }
Future for one AsyncOutput write operation.

Panics

Future::poll panics when called again after this future has returned Poll::Ready.

Type Parameters

  • 'a: Shared lifetime of the output borrow and source slice.
  • O: Asynchronous output type.

Implementations

Source

impl<'a, O> WriteFuture<'a, O>
where O: AsyncOutput + ?Sized,

pub const fn new(output: Pin<&'a mut O>, input: &'a [O::Item]) -> Self

Creates a write future from a pinned output.

Parameters
  • output: Pinned asynchronous output.
  • input: Source storage.
Returns

Returns a future representing one write operation.