Trait BinaryWriteExt Copy item path Source pub trait BinaryWriteExt: Write {
Show 32 methods // Required methods
fn write_u8 (&mut self, value: u8 ) -> Result <() >;
fn write_i8 (&mut self, value: i8 ) -> Result <() >;
fn write_u16_be (&mut self, value: u16 ) -> Result <() >;
fn write_u16_le (&mut self, value: u16 ) -> Result <() >;
fn write_i16_be (&mut self, value: i16 ) -> Result <() >;
fn write_i16_le (&mut self, value: i16 ) -> Result <() >;
fn write_u32_be (&mut self, value: u32 ) -> Result <() >;
fn write_u32_le (&mut self, value: u32 ) -> Result <() >;
fn write_i32_be (&mut self, value: i32 ) -> Result <() >;
fn write_i32_le (&mut self, value: i32 ) -> Result <() >;
fn write_u64_be (&mut self, value: u64 ) -> Result <() >;
fn write_u64_le (&mut self, value: u64 ) -> Result <() >;
fn write_i64_be (&mut self, value: i64 ) -> Result <() >;
fn write_i64_le (&mut self, value: i64 ) -> Result <() >;
fn write_u128_be (&mut self, value: u128 ) -> Result <() >;
fn write_u128_le (&mut self, value: u128 ) -> Result <() >;
fn write_i128_be (&mut self, value: i128 ) -> Result <() >;
fn write_i128_le (&mut self, value: i128 ) -> Result <() >;
fn write_f32_be (&mut self, value: f32 ) -> Result <() >;
fn write_f32_le (&mut self, value: f32 ) -> Result <() >;
fn write_f64_be (&mut self, value: f64 ) -> Result <() >;
fn write_f64_le (&mut self, value: f64 ) -> Result <() >;
// Provided methods
fn write_u16 (&mut self, value: u16 , order: ByteOrder ) -> Result <() > { ... }
fn write_i16 (&mut self, value: i16 , order: ByteOrder ) -> Result <() > { ... }
fn write_u32 (&mut self, value: u32 , order: ByteOrder ) -> Result <() > { ... }
fn write_i32 (&mut self, value: i32 , order: ByteOrder ) -> Result <() > { ... }
fn write_u64 (&mut self, value: u64 , order: ByteOrder ) -> Result <() > { ... }
fn write_i64 (&mut self, value: i64 , order: ByteOrder ) -> Result <() > { ... }
fn write_u128 (&mut self, value: u128 , order: ByteOrder ) -> Result <() > { ... }
fn write_i128 (&mut self, value: i128 , order: ByteOrder ) -> Result <() > { ... }
fn write_f32 (&mut self, value: f32 , order: ByteOrder ) -> Result <() > { ... }
fn write_f64 (&mut self, value: f64 , order: ByteOrder ) -> Result <() > { ... }
}Expand description Extension methods for writing binary scalar values to Write streams.
Multi-byte values can be written either with explicit byte-order suffixes
or with a runtime ByteOrder argument. All methods delegate to
Write::write_all , so they either write the complete encoded value or
return the first I/O error.
Writes one unsigned byte.
 Parameters
 Errors
Returns an I/O error from the underlying writer.
Writes one signed byte.
 Parameters
 Errors
Returns an I/O error from the underlying writer.
Writes a big-endian u16.
 Parameters
 Errors
Returns an I/O error from the underlying writer.
Writes a little-endian u16.
 Parameters
 Errors
Returns an I/O error from the underlying writer.
Writes a big-endian i16.
 Parameters
 Errors
Returns an I/O error from the underlying writer.
Writes a little-endian i16.
 Parameters
 Errors
Returns an I/O error from the underlying writer.
Writes a big-endian u32.
 Parameters
 Errors
Returns an I/O error from the underlying writer.
Writes a little-endian u32.
 Parameters
 Errors
Returns an I/O error from the underlying writer.
Writes a big-endian i32.
 Parameters
 Errors
Returns an I/O error from the underlying writer.
Writes a little-endian i32.
 Parameters
 Errors
Returns an I/O error from the underlying writer.
Writes a big-endian u64.
 Parameters
 Errors
Returns an I/O error from the underlying writer.
Writes a little-endian u64.
 Parameters
 Errors
Returns an I/O error from the underlying writer.
Writes a big-endian i64.
 Parameters
 Errors
Returns an I/O error from the underlying writer.
Writes a little-endian i64.
 Parameters
 Errors
Returns an I/O error from the underlying writer.
Writes a big-endian u128.
 Parameters
 Errors
Returns an I/O error from the underlying writer.
Writes a little-endian u128.
 Parameters
 Errors
Returns an I/O error from the underlying writer.
Writes a big-endian i128.
 Parameters
 Errors
Returns an I/O error from the underlying writer.
Writes a little-endian i128.
 Parameters
 Errors
Returns an I/O error from the underlying writer.
Writes a big-endian IEEE-754 f32.
 Parameters
 Errors
Returns an I/O error from the underlying writer.
Writes a little-endian IEEE-754 f32.
 Parameters
 Errors
Returns an I/O error from the underlying writer.
Writes a big-endian IEEE-754 f64.
 Parameters
 Errors
Returns an I/O error from the underlying writer.
Writes a little-endian IEEE-754 f64.
 Parameters
 Errors
Returns an I/O error from the underlying writer.
Writes a u16 using order.
 Parameters
value: Value to encode.
order: Byte order used to encode the value.
 Errors
Returns an I/O error from the underlying writer.
Writes an i16 using order.
 Parameters
value: Value to encode.
order: Byte order used to encode the value.
 Errors
Returns an I/O error from the underlying writer.
Writes a u32 using order.
 Parameters
value: Value to encode.
order: Byte order used to encode the value.
 Errors
Returns an I/O error from the underlying writer.
Writes an i32 using order.
 Parameters
value: Value to encode.
order: Byte order used to encode the value.
 Errors
Returns an I/O error from the underlying writer.
Writes a u64 using order.
 Parameters
value: Value to encode.
order: Byte order used to encode the value.
 Errors
Returns an I/O error from the underlying writer.
Writes an i64 using order.
 Parameters
value: Value to encode.
order: Byte order used to encode the value.
 Errors
Returns an I/O error from the underlying writer.
Writes a u128 using order.
 Parameters
value: Value to encode.
order: Byte order used to encode the value.
 Errors
Returns an I/O error from the underlying writer.
Writes an i128 using order.
 Parameters
value: Value to encode.
order: Byte order used to encode the value.
 Errors
Returns an I/O error from the underlying writer.
Writes an IEEE-754 f32 using order.
 Parameters
value: Value to encode.
order: Byte order used to encode the value.
 Errors
Returns an I/O error from the underlying writer.
Writes an IEEE-754 f64 using order.
 Parameters
value: Value to encode.
order: Byte order used to encode the value.
 Errors
Returns an I/O error from the underlying writer.