Crate qubit_io

Crate qubit_io 

Qubit IO

Small I/O trait utilities for Rust.

This crate provides named, object-safe composition traits for common std::io capability combinations and small extension traits for recurring standard-library I/O patterns. The concrete trait definitions live in dedicated modules and are re-exported from the crate root for ergonomic use.

Modules

prelude
Common extension and composition traits for Qubit IO users.

Structs

BinaryReader
Reader wrapper for binary scalar and length-prefixed string decoding.
BinaryWriter
Writer wrapper for binary scalar and length-prefixed string encoding.
ChecksumReader
Reader wrapper that updates a checksum hasher with bytes read.
ChecksumWriter
Writer wrapper that updates a checksum hasher with bytes written.
CountingReader
Reader wrapper that counts successfully read bytes.
CountingWriter
Writer wrapper that counts successfully written bytes.
Leb128Reader
Reader wrapper for LEB128 integers and LEB128 length-prefixed strings.
Leb128Writer
Writer wrapper for LEB128 integers and LEB128 length-prefixed strings.
LimitReader
Reader wrapper that exposes at most a fixed number of bytes.
LimitWriter
Writer wrapper that accepts at most a fixed number of bytes.
PositionGuard
Guard that restores a seekable stream to its original position.
TeeReader
Reader wrapper that mirrors read bytes into a branch writer.
TeeWriter
Writer wrapper that mirrors accepted bytes into a branch writer.
ZigZagReader
Reader wrapper for ZigZag encoded signed integers.
ZigZagWriter
Writer wrapper for ZigZag encoded signed integers.

Enums

ByteOrder
Byte order used when encoding or decoding multi-byte scalar values.
Streams
Stream utility namespace.

Traits

BinaryReadExt
Extension methods for reading binary scalar values from Read streams.
BinaryWriteExt
Extension methods for writing binary scalar values to Write streams.
BufReadExt
Extension methods for BufRead values.
BufReadSeek
Object-safe capability trait for values that can be buffered-read and repositioned.
Leb128ReadExt
Extension methods for reading LEB128 encoded integers.
Leb128WriteExt
Extension methods for writing LEB128 encoded integers.
ReadExt
Extension methods for Read values.
ReadSeek
Object-safe capability trait for values that can be read and repositioned.
ReadSeekExt
Extension methods for values that implement both Read and Seek.
ReadWrite
Object-safe capability trait for values that can be both read and written.
ReadWriteSeek
Object-safe capability trait for values that can be read, written, and repositioned.
SeekExt
Extension methods for Seek values.
StringReadExt
Extension methods for reading length-prefixed UTF-8 strings.
StringWriteExt
Extension methods for writing length-prefixed UTF-8 strings.
WriteSeek
Object-safe capability trait for values that can be written and repositioned.
WriteSeekExt
Extension methods for values that implement both Write and Seek.
ZigZagReadExt
Extension methods for reading ZigZag encoded signed integers.
ZigZagWriteExt
Extension methods for writing ZigZag encoded signed integers.