pub struct BoxAsyncOutput<O>where
O: AsyncOutput + ?Sized,{ /* private fields */ }Expand description
Adapts an owned pinned boxed asynchronous output, including a trait object.
Type Parameters
O: The boxed asynchronous output type, which may be unsized and non-Unpin.
Implementations
Sourceimpl<O> BoxAsyncOutput<O>where
O: AsyncOutput + ?Sized,
impl<O> BoxAsyncOutput<O>where
O: AsyncOutput + ?Sized,
Sourcepub fn get_ref(&self) -> &O
pub fn get_ref(&self) -> &O
Returns a shared reference to the boxed asynchronous output.
Returns
Returns the wrapped asynchronous output.
Sourcepub fn get_pin_mut(self: Pin<&mut Self>) -> Pin<&mut O>
pub fn get_pin_mut(self: Pin<&mut Self>) -> Pin<&mut O>
Projects a pinned adapter to its pinned boxed asynchronous output.
Returns
Returns a pinned mutable reference to the wrapped output without moving it.
Sourcepub fn into_inner(self) -> Pin<Box<O>>
pub fn into_inner(self) -> Pin<Box<O>>
Consumes this adapter and returns its pinned boxed asynchronous output.
Returns
Returns the pinned boxed output so a potentially non-Unpin value stays
pinned after extraction.