TeeReader

Struct TeeReader 

pub struct TeeReader<R, W> { /* private fields */ }
Reader wrapper that mirrors read bytes into a branch writer.

TeeReader forwards reads to the source reader and writes every successfully read byte into the branch writer while the stream is consumed. If the branch writer fails, the source bytes have already been read from the inner reader and the branch error is returned.

Examples

use std::io::{
    Cursor,
    Read,
};

use qubit_io::TeeReader;

let source = Cursor::new(b"abc".to_vec());
let branch = Vec::new();
let mut reader = TeeReader::new(source, branch);

let mut data = Vec::new();
reader.read_to_end(&mut data)?;
let (_source, branch) = reader.into_inner();

assert_eq!(b"abc", data.as_slice());
assert_eq!(b"abc", branch.as_slice());

Implementations

Source

impl<R, W> TeeReader<R, W>

pub fn new(reader: R, branch: W) -> Self

Creates a tee reader.

Parameters
  • reader: Source reader.
  • branch: Writer that receives the bytes successfully read.
Returns

A new tee reader.

pub fn reader_ref(&self) -> &R

Returns an immutable reference to the source reader.

Returns

The source reader reference.

pub fn reader_mut(&mut self) -> &mut R

Returns a mutable reference to the source reader.

Returns

The source reader reference.

pub fn branch_ref(&self) -> &W

Returns an immutable reference to the branch writer.

Returns

The branch writer reference.

pub fn branch_mut(&mut self) -> &mut W

Returns a mutable reference to the branch writer.

Returns

The branch writer reference.

pub fn into_inner(self) -> (R, W)

Consumes this wrapper and returns the source reader and branch writer.

Returns

A tuple containing the source reader and branch writer.