pub struct TeeReader<R, W> { /* private fields */ }Expand description
Reader wrapper that mirrors read bytes into a branch writer.
TeeReader forwards reads to the source reader and writes every
successfully read byte into the branch writer while the stream is consumed.
If the branch writer fails, the source bytes have already been read from the
inner reader and the branch error is returned.
Examples
use std::io::{
Cursor,
Read,
};
use qubit_io::TeeReader;
let source = Cursor::new(b"abc".to_vec());
let branch = Vec::new();
let mut reader = TeeReader::new(source, branch);
let mut data = Vec::new();
reader.read_to_end(&mut data)?;
let (_source, branch) = reader.into_inner();
assert_eq!(b"abc", data.as_slice());
assert_eq!(b"abc", branch.as_slice());Implementations
Sourceimpl<R, W> TeeReader<R, W>
impl<R, W> TeeReader<R, W>
Sourcepub fn reader_ref(&self) -> &R
pub fn reader_ref(&self) -> &R
Sourcepub fn reader_mut(&mut self) -> &mut R
pub fn reader_mut(&mut self) -> &mut R
Sourcepub fn branch_ref(&self) -> &W
pub fn branch_ref(&self) -> &W
Sourcepub fn branch_mut(&mut self) -> &mut W
pub fn branch_mut(&mut self) -> &mut W
Sourcepub fn into_inner(self) -> (R, W)
pub fn into_inner(self) -> (R, W)
Consumes this wrapper and returns the source reader and branch writer.
Returns
A tuple containing the source reader and branch writer.