TeeWriter

Struct TeeWriter 

pub struct TeeWriter<P, B> { /* private fields */ }
Writer wrapper that mirrors accepted bytes into a branch writer.

TeeWriter writes to the primary writer first, then writes exactly the accepted bytes into the branch writer with Write::write_all. If the branch writer fails, the primary writer may already have accepted bytes and the branch error is returned.

Seeking moves the primary writer first, then seeks the branch writer to the primary writer’s resulting absolute position. If the branch seek fails, the primary writer may already have moved.

Examples

use std::io::Write;

use qubit_io::TeeWriter;

let primary = Vec::new();
let branch = Vec::new();
let mut writer = TeeWriter::new(primary, branch);

writer.write_all(b"abc")?;
let (primary, branch) = writer.into_inner();

assert_eq!(b"abc", primary.as_slice());
assert_eq!(b"abc", branch.as_slice());

Implementations

Source

impl<P, B> TeeWriter<P, B>

pub fn new(primary: P, branch: B) -> Self

Creates a tee writer.

Parameters
  • primary: Primary destination writer.
  • branch: Secondary writer that mirrors accepted bytes.
Returns

A new tee writer.

pub fn primary_ref(&self) -> &P

Returns an immutable reference to the primary writer.

Returns

The primary writer reference.

pub fn primary_mut(&mut self) -> &mut P

Returns a mutable reference to the primary writer.

Returns

The primary writer reference.

pub fn branch_ref(&self) -> &B

Returns an immutable reference to the branch writer.

Returns

The branch writer reference.

pub fn branch_mut(&mut self) -> &mut B

Returns a mutable reference to the branch writer.

Returns

The branch writer reference.

pub fn into_inner(self) -> (P, B)

Consumes this wrapper and returns both wrapped writers.

Returns

A tuple containing the primary writer and branch writer.