pub struct WriteFuture<'a, O>where
O: AsyncOutput + ?Sized,{ /* private fields */ }Expand description
Future for one AsyncOutput write operation.
Panics
Future::poll panics when called again after this future has returned
Poll::Ready.
Type Parameters
'a: Shared lifetime of the output borrow and source slice.O: Asynchronous output type.
Implementations
Sourceimpl<'a, O> WriteFuture<'a, O>where
O: AsyncOutput + ?Sized,
impl<'a, O> WriteFuture<'a, O>where
O: AsyncOutput + ?Sized,